==> hs-polyparse-1.9.txz: usr/local/lib/cabal/ghc-7.6.3/polyparse-1.9/register.sh <==
#!/bin/sh
echo 'name: polyparse
version: 1.9
id: polyparse-1.9-b5f5bd214b1b2a7afc4372c48e61bd4a

license: LGPL
copyright:
maintainer: author
stability:
homepage: http://code.haskell.org/~malcolm/polyparse/
package-url:
synopsis: A variety of alternative parser combinator libraries.
description: A variety of alternative parser combinator libraries, including
             the original HuttonMeijer set.  The Poly sets have features like
             good error reporting, arbitrary token type, running state, lazy
             parsing, and so on.  Finally, Text.Parse is a proposed
             replacement for the standard Read class, for better
             deserialisation of Haskell values from Strings.
category: Text, Parsing
author: Malcolm Wallace <Malcolm.Wallace@me.com>
exposed: True
exposed-modules: Text.ParserCombinators.Poly.ByteString
                 Text.ParserCombinators.Poly.ByteStringChar Text.Parse.ByteString
                 Text.ParserCombinators.Poly.Text
                 Text.ParserCombinators.Poly.StateText
                 Text.ParserCombinators.HuttonMeijer
                 Text.ParserCombinators.HuttonMeijerWallace
                 Text.ParserCombinators.Poly Text.ParserCombinators.Poly.Base
                 Text.ParserCombinators.Poly.Result
                 Text.ParserCombinators.Poly.Parser
                 Text.ParserCombinators.Poly.Plain Text.ParserCombinators.Poly.Lazy
                 Text.ParserCombinators.Poly.StateParser
                 Text.ParserCombinators.Poly.State
                 Text.ParserCombinators.Poly.StateLazy
                 Text.ParserCombinators.Poly.Lex Text.Parse
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/cabal/ghc-7.6.3/polyparse-1.9
library-dirs: /usr/local/lib/cabal/ghc-7.6.3/polyparse-1.9
              /usr/local/lib
hs-libraries: HSpolyparse-1.9
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.6.0.1-f7bdc8987bd5928e0ee6e8cc8b246a88
         bytestring-0.10.0.2-59abd9894532f476aabac207680aae43
         text-0.11.3.1-b49365bcfaf3954e4484c36c86c98126
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/cabal/ghc-7.6.3/polyparse-1.9/html/polyparse.haddock
haddock-html: /usr/local/share/doc/cabal/ghc-7.6.3/polyparse-1.9/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> hs-polyparse-1.9_6.txz: usr/local/lib/cabal/ghc-7.8.3/polyparse-1.9/register.sh <==
#!/bin/sh
export PATH='/usr/local/libexec/ccache:/sbin:/bin:/usr/sbin:/usr/bin:/usr/games:/usr/local/sbin:/usr/local/bin:/root/bin'
echo 'name: polyparse
version: 1.9
id: polyparse-1.9-e5d39531fce3e66555103149d2a92d4a

license: LGPL
copyright:
maintainer: author
stability:
homepage: http://code.haskell.org/~malcolm/polyparse/
package-url:
synopsis: A variety of alternative parser combinator libraries.
description: A variety of alternative parser combinator libraries, including
             the original HuttonMeijer set.  The Poly sets have features like
             good error reporting, arbitrary token type, running state, lazy
             parsing, and so on.  Finally, Text.Parse is a proposed
             replacement for the standard Read class, for better
             deserialisation of Haskell values from Strings.
category: Text, Parsing
author: Malcolm Wallace <Malcolm.Wallace@me.com>
exposed: True
exposed-modules: Text.ParserCombinators.HuttonMeijer
                 Text.ParserCombinators.HuttonMeijerWallace
                 Text.ParserCombinators.Poly Text.ParserCombinators.Poly.Base
                 Text.ParserCombinators.Poly.Result
                 Text.ParserCombinators.Poly.Parser
                 Text.ParserCombinators.Poly.Plain Text.ParserCombinators.Poly.Lazy
                 Text.ParserCombinators.Poly.StateParser
                 Text.ParserCombinators.Poly.State
                 Text.ParserCombinators.Poly.StateLazy
                 Text.ParserCombinators.Poly.Lex Text.Parse
                 Text.ParserCombinators.Poly.ByteString
                 Text.ParserCombinators.Poly.ByteStringChar Text.Parse.ByteString
                 Text.ParserCombinators.Poly.Text
                 Text.ParserCombinators.Poly.StateText
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/cabal/ghc-7.8.3/polyparse-1.9
library-dirs: /usr/local/lib/cabal/ghc-7.8.3/polyparse-1.9
              /usr/local/lib
hs-libraries: HSpolyparse-1.9
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.7.0.1-812360bc88c9859b8259f0d90b6e2faa
         bytestring-0.10.4.0-2182937da706a7ad10a5093b31e299db
         text-1.1.0.0-ae5f08307fb9d06679d77b9fce515032
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/cabal/ghc-7.8.3/polyparse-1.9/html/polyparse.haddock
haddock-html: /usr/local/share/doc/cabal/ghc-7.8.3/polyparse-1.9/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
